@@ -26,34 +26,6 @@ class SesClient(AbstractClient):
     _service = 'ses'
 
 
-    def BatchSendEmail(self, request):
-        """This API is used to send a TEXT or HTML email to multiple recipients at a time for marketing or notification purposes. By default, you can send emails using a template only. To send custom content, please contact your sales rep to enable this feature. You need to create a recipient group with email addresses first and then send emails by group ID. SES supports scheduled and recurring email sending tasks. You need to pass in `TimedParam` for a scheduled task and `CycleParam` for a recurring one.
-
-        :param request: Request instance for BatchSendEmail.
-        :type request: :class:`tencentcloud.ses.v20201002.models.BatchSendEmailRequest`
-        :rtype: :class:`tencentcloud.ses.v20201002.models.BatchSendEmailResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("BatchSendEmail", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.BatchSendEmailResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def CreateEmailAddress(self, request):
         """After the sender domain is verified, you need a sender address to send emails. For example, if your sender domain is mail.qcloud.com, your sender address can be service@mail.qcloud.com. If you want to display your name (such as "Tencent Cloud") in the inbox list of the recipients, the sender address should be in the format of `Tencent Cloud <email address>`. Please note that there must be a space between your name and the first angle bracket.
 
@@ -110,35 +82,6 @@ class SesClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def CreateEmailTemplate(self, request):
-        """This API is used to create a TEXT or HTML email template. To create an HTML template, ensure that it does not include external CSS files. You can use {{variable name}} to specify a variable in the template.
-        Note: Only an approved template can be used to send emails.
-
-        :param request: Request instance for CreateEmailTemplate.
-        :type request: :class:`tencentcloud.ses.v20201002.models.CreateEmailTemplateRequest`
-        :rtype: :class:`tencentcloud.ses.v20201002.models.CreateEmailTemplateResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("CreateEmailTemplate", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateEmailTemplateResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def CreateReceiver(self, request):
         """This API is used to create a recipient group, which is the list of target email addresses for batch sending emails. After creating a group, you need to upload recipient email addresses. Then, you can create a sending task and select the group to batch send emails.
 
@@ -391,34 +334,6 @@ class SesClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def GetSendEmailStatus(self, request):
-        """This API is used to get email sending status. Only data within 30 days can be queried.
-
-        :param request: Request instance for GetSendEmailStatus.
-        :type request: :class:`tencentcloud.ses.v20201002.models.GetSendEmailStatusRequest`
-        :rtype: :class:`tencentcloud.ses.v20201002.models.GetSendEmailStatusResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("GetSendEmailStatus", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.GetSendEmailStatusResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def GetStatisticsReport(self, request):
         """This API is used to get the email sending statistics over a recent period, including data on sent emails, delivery success rate, open rate, bounce rate, and so on.
 
@@ -664,34 +579,6 @@ class SesClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def UpdateEmailTemplate(self, request):
-        """This API is used to update an email template. An updated template must be approved again before it can be used.
-
-        :param request: Request instance for UpdateEmailTemplate.
-        :type request: :class:`tencentcloud.ses.v20201002.models.UpdateEmailTemplateRequest`
-        :rtype: :class:`tencentcloud.ses.v20201002.models.UpdateEmailTemplateResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("UpdateEmailTemplate", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.UpdateEmailTemplateResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
