@@ -176,6 +176,12 @@ INTERNALERROR_TASKLIFESTATEERROR = 'InternalError.TaskLifeStateError'
 # No task found
 INTERNALERROR_TASKNOTFOUND = 'InternalError.TaskNotFound'
 
+# 
+INTERNALERROR_TRADECOMMON = 'InternalError.TradeCommon'
+
+# 
+INTERNALERROR_TRADEINSUFFICIENTBALANCE = 'InternalError.TradeInsufficientBalance'
+
 # Internal error.
 INTERNALERROR_UNEXCEPTEDINTERNAL = 'InternalError.UnexceptedInternal'
 
